@@ -208,10 +208,17 @@ static gint
 css_parser_parse_string (const gchar *str, gint start_pos, gint end_pos, gchar **ret_val)
 {
 	guchar c;
+	gchar *buffer;
+	gint buffer_size, buffer_size_max;
 	gchar quote_char, nonquote_char;
 	gint pos = start_pos;
 	gboolean has_escape = FALSE;
 	
+
+	buffer_size = 0;
+	buffer_size_max = 8;
+	buffer = g_malloc (buffer_size_max);
+
 	quote_char = str[pos++];
 	nonquote_char = (quote_char == '"') ? '\'': '"';
 
@@ -232,11 +239,17 @@ css_parser_parse_string (const gchar *str, gint start_pos, gint end_pos, gchar *
 		else if ((c >= '(' && c <= '~') ||
 			 c == ' ' || c == '!' || (c >= '#' && c <= '&') || c == '\t' ||
 			 c == nonquote_char) {
+			if (!has_escape) {
+				if (buffer_size == buffer_size_max)
+					buffer = g_realloc (buffer, (buffer_size_max <<= 1));
+				buffer[buffer_size++] = c;
+			}
 		}
 		else if (c > 0x80) {
 			g_error ("support unicode!\n");
 		}
 		else {
+			g_free (buffer);
 			return -1;
 		}
 	}
@@ -245,10 +258,11 @@ css_parser_parse_string (const gchar *str, gint start_pos, gint end_pos, gchar *
 		if (has_escape)
 			*ret_val = css_parser_unescape (str + start_pos, pos - start_pos);
 		else 
-			*ret_val = g_strndup (str + start_pos,
-					      pos - start_pos);
+			*ret_val = g_strndup (buffer, buffer_size);
 	}
 
+	g_free (buffer);
+
 	return pos;
 
 }
