@@ -208,11 +208,12 @@ html_default_style_new (void)
 	HtmlStyleBorder *border = html_style_border_new ();
 	HtmlStyleOutline *outline = html_style_outline_new ();
 	GtkStyle *gtk_style;
-        gchar *font_name;
-        GtkSettings *settings;
-        PangoFontDescription *font_desc;
-        const gchar *family;
-        gfloat size;
+	gchar *font_name;
+	GtkSettings *settings;
+	PangoFontDescription *font_desc;
+	const gchar *family;
+	gfloat size;
+	HtmlColor *color;
 
 	/* Set refcount to 1 so it never will be deallocated */
 	result->refcount = 1;
@@ -246,8 +247,13 @@ html_default_style_new (void)
                                              HTML_FONT_DECORATION_NONE, 
                                              size);
 	
-	/* Set the default color to match the GTK+ theme */
-	html_style_set_color (result, html_style_get_gtk_text_color (gtk_style));
+	/*
+	 * Set the default color to match the GTK+ theme  
+	 * and free the HtmlColor
+	 */
+	color = html_style_get_gtk_text_color (gtk_style);
+	html_style_set_color (result, color);
+	html_color_unref (color);
 	g_object_unref (gtk_style);
 	
 	return result;
